@@ -13,20 +13,19 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from debtcollector import removals
 import flask
-import webob.dec
 from oslo_config import cfg
-import oslo_messaging as messaging
 from oslo_log import log as logging
+import oslo_messaging as messaging
 from oslo_middleware import base
 from oslo_middleware import request_id
 from oslo_serialization import jsonutils
 from oslo_utils import strutils
+import webob.dec
 
+from designate import context
 from designate import exceptions
 from designate import notifications
-from designate import context
 from designate import objects
 from designate.objects.adapters import DesignateAdapter
 
@@ -52,42 +51,45 @@ def auth_pipeline_factory(loader, global_conf, **local_conf):
 
 
 class ContextMiddleware(base.Middleware):
-    def _extract_sudo(self, ctxt, request):
-        if request.headers.get('X-Auth-Sudo-Tenant-ID') or \
-                request.headers.get('X-Auth-Sudo-Project-ID'):
-            ctxt.sudo(
-                request.headers.get('X-Auth-Sudo-Tenant-ID') or
-                request.headers.get('X-Auth-Sudo-Project-ID')
-            )
+    @staticmethod
+    def _extract_sudo(ctxt, request):
+        if request.headers.get('X-Auth-Sudo-Project-ID'):
+            ctxt.sudo(request.headers.get('X-Auth-Sudo-Project-ID'))
+        elif request.headers.get('X-Auth-Sudo-Tenant-ID'):
+            ctxt.sudo(request.headers.get('X-Auth-Sudo-Tenant-ID'))
 
-    def _extract_all_projects(self, ctxt, request):
+    @staticmethod
+    def _extract_all_projects(ctxt, request):
         ctxt.all_tenants = False
         if request.headers.get('X-Auth-All-Projects'):
             value = request.headers.get('X-Auth-All-Projects')
             ctxt.all_tenants = strutils.bool_from_string(value)
 
-        for i in ('all_projects', 'all_tenants', ):
-            if i in request.GET:
-                value = request.GET.pop(i)
+        for name in ('all_projects', 'all_tenants', ):
+            if name in request.GET:
+                value = request.GET.pop(name)
                 ctxt.all_tenants = strutils.bool_from_string(value)
 
-    def _extract_dns_hide_counts(self, ctxt, request):
+    @staticmethod
+    def _extract_dns_hide_counts(ctxt, request):
         ctxt.hide_counts = False
         value = request.headers.get('OpenStack-DNS-Hide-Counts')
         if value:
             ctxt.hide_counts = strutils.bool_from_string(value)
 
-    def _extract_edit_managed_records(self, ctxt, request):
+    @staticmethod
+    def _extract_edit_managed_records(ctxt, request):
         ctxt.edit_managed_records = False
         if 'edit_managed_records' in request.GET:
             value = request.GET.pop('edit_managed_records')
             ctxt.edit_managed_records = strutils.bool_from_string(value)
         elif request.headers.get('X-Designate-Edit-Managed-Records'):
-            ctxt.edit_managed_records = \
-                strutils.bool_from_string(
-                    request.headers.get('X-Designate-Edit-Managed-Records'))
+            ctxt.edit_managed_records = strutils.bool_from_string(
+                request.headers.get('X-Designate-Edit-Managed-Records')
+            )
 
-    def _extract_client_addr(self, ctxt, request):
+    @staticmethod
+    def _extract_client_addr(ctxt, request):
         if hasattr(request, 'client_addr'):
             ctxt.client_addr = request.client_addr
 
@@ -118,7 +120,7 @@ class KeystoneContextMiddleware(ContextMiddleware):
         headers = request.headers
 
         try:
-            if headers['X-Identity-Status'] is 'Invalid':
+            if headers['X-Identity-Status'] == 'Invalid':
                 # TODO(graham) fix the return to use non-flask resources
                 return flask.Response(status=401)
         except KeyError:
@@ -126,15 +128,13 @@ class KeystoneContextMiddleware(ContextMiddleware):
             pass
 
         tenant_id = headers.get('X-Tenant-ID')
-        if tenant_id is None:
-            return flask.Response(status=401)
 
+        catalog = None
         if headers.get('X-Service-Catalog'):
             catalog = jsonutils.loads(headers.get('X-Service-Catalog'))
-        else:
-            catalog = None
 
         roles = headers.get('X-Roles').split(',')
+        system_scope = headers.get('Openstack-System-Scope')
 
         try:
             self.make_context(
@@ -143,7 +143,8 @@ class KeystoneContextMiddleware(ContextMiddleware):
                 user_id=headers.get('X-User-ID'),
                 project_id=tenant_id,
                 roles=roles,
-                service_catalog=catalog
+                service_catalog=catalog,
+                system_scope=system_scope
             )
         except exceptions.Forbidden:
             return flask.Response(status=403)
@@ -160,7 +161,7 @@ class NoAuthContextMiddleware(ContextMiddleware):
 
         self.make_context(
             request,
-            auth_token=headers.get('X-Auth-Token', None),
+            auth_token=headers.get('X-Auth-Token'),
             user_id=headers.get('X-Auth-User-ID', 'noauth-user'),
             project_id=headers.get('X-Auth-Project-ID', 'noauth-project'),
             roles=headers.get('X-Roles', 'admin').split(',')
@@ -270,7 +271,6 @@ class FaultWrapperMiddleware(base.Middleware):
         pass
 
     def _handle_exception(self, request, e, status=500, response=None):
-
         response = response or {}
         # Log the exception ASAP unless it is a 404 Not Found
         if not getattr(e, 'expected', False):
@@ -306,11 +306,11 @@ class FaultWrapperMiddleware(base.Middleware):
                               response=jsonutils.dump_as_bytes(response))
 
 
-class ValidationErrorMiddleware(base.Middleware):
+class APIv2ValidationErrorMiddleware(base.Middleware):
 
     def __init__(self, application):
-        super(ValidationErrorMiddleware, self).__init__(application)
-
+        super(APIv2ValidationErrorMiddleware, self).__init__(application)
+        self.api_version = 'API_v2'
         LOG.info('Starting designate validation middleware')
 
     @webob.dec.wsgify
@@ -324,7 +324,6 @@ class ValidationErrorMiddleware(base.Middleware):
             return self._handle_errors(request, e)
 
     def _handle_errors(self, request, exception):
-
         response = {}
 
         headers = [
@@ -332,14 +331,13 @@ class ValidationErrorMiddleware(base.Middleware):
         ]
 
         rendered_errors = DesignateAdapter.render(
-            self.api_version, exception.errors, failed_object=exception.object)
+            self.api_version, exception.errors, failed_object=exception.object
+        )
 
         url = getattr(request, 'url', None)
 
         response['code'] = exception.error_code
-
         response['type'] = exception.error_type or 'unknown'
-
         response['errors'] = rendered_errors
 
         # Return the new response
@@ -355,34 +353,3 @@ class ValidationErrorMiddleware(base.Middleware):
 
         return flask.Response(status=exception.error_code, headers=headers,
                               response=jsonutils.dump_as_bytes(response))
-
-
-class APIv2ValidationErrorMiddleware(ValidationErrorMiddleware):
-    def __init__(self, application):
-        super(APIv2ValidationErrorMiddleware, self).__init__(application)
-        self.api_version = 'API_v2'
-
-
-class SSLMiddleware(base.Middleware):
-    """A middleware that replaces the request wsgi.url_scheme environment
-    variable with the value of HTTP header configured in
-    secure_proxy_ssl_header if exists in the incoming request.
-    This is useful if the server is behind a SSL termination proxy.
-
-    Code nabbed from Heat.
-    """
-    # Replaced by oslo.middleware's http_proxy_to_wsgi middleware
-    @removals.remove
-    def __init__(self, application):
-        super(SSLMiddleware, self).__init__(application)
-        LOG.info('Starting designate ssl middleware')
-        self.secure_proxy_ssl_header = 'HTTP_{0}'.format(
-            cfg.CONF['service:api'].secure_proxy_ssl_header.upper().
-            replace('-', '_'))
-        self.override = cfg.CONF['service:api'].override_proto
-
-    def process_request(self, request):
-        request.environ['wsgi.url_scheme'] = request.environ.get(
-            self.secure_proxy_ssl_header, request.environ['wsgi.url_scheme'])
-        if self.override:
-            request.environ['wsgi.url_scheme'] = self.override
