@@ -13,13 +13,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import pecan
 from oslo_config import cfg
 from oslo_log import log as logging
+import pecan
 
 from designate.api.v2.controllers import rest
 from designate.common import keystone
-from designate import exceptions
 from designate.objects.adapters import DesignateAdapter
 from designate.objects import QuotaList
 
@@ -64,15 +63,6 @@ class QuotasController(rest.RestController):
 
         quotas = DesignateAdapter.parse('API_v2', body, QuotaList())
 
-        # The get_quotas lookup will always return the default quotas
-        # if the context does not have a project_id (system scoped token) and
-        # the all_tenants boolean is false. Let's require all_tenants for
-        # contexts with no project ID.
-        if context.project_id is None and not context.all_tenants:
-            raise exceptions.MissingProjectID(
-                "The all-projects flag must be used when using non-project "
-                "scoped tokens.")
-
         for quota in quotas:
             self.central_api.set_quota(context, tenant_id, quota.resource,
                                        quota.hard_limit)
