@@ -12,15 +12,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import pecan
 from oslo_log import log as logging
+import pecan
 
-from designate import utils
 from designate.api.v2.controllers import rest
-from designate.objects import Tld
 from designate.objects.adapters import DesignateAdapter
-from designate.i18n import _LI
-
+from designate.objects import Tld
+from designate import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -38,7 +36,7 @@ class TldsController(rest.RestController):
 
         tld = self.central_api.get_tld(context, tld_id)
 
-        LOG.info(_LI("Retrieved %(tld)s"), {'tld': tld})
+        LOG.info("Retrieved %(tld)s", {'tld': tld})
 
         return DesignateAdapter.render('API_v2', tld, request=request)
 
@@ -60,7 +58,7 @@ class TldsController(rest.RestController):
         tlds = self.central_api.find_tlds(
             context, criterion, marker, limit, sort_key, sort_dir)
 
-        LOG.info(_LI("Retrieved %(tlds)s"), {'tlds': tlds})
+        LOG.info("Retrieved %(tlds)s", {'tlds': tlds})
 
         return DesignateAdapter.render('API_v2', tlds, request=request)
 
@@ -79,7 +77,7 @@ class TldsController(rest.RestController):
         # Create the tld
         tld = self.central_api.create_tld(context, tld)
 
-        LOG.info(_LI("Created %(tld)s"), {'tld': tld})
+        LOG.info("Created %(tld)s", {'tld': tld})
 
         response.status_int = 201
 
@@ -100,7 +98,7 @@ class TldsController(rest.RestController):
         body = request.body_dict
         response = pecan.response
         if request.content_type == 'application/json-patch+json':
-            raise NotImplemented('json-patch not implemented')
+            raise NotImplementedError('json-patch not implemented')
 
         # Fetch the existing tld
         tld = self.central_api.get_tld(context, tld_id)
@@ -111,7 +109,7 @@ class TldsController(rest.RestController):
 
         tld = self.central_api.update_tld(context, tld)
 
-        LOG.info(_LI("Updated %(tld)s"), {'tld': tld})
+        LOG.info("Updated %(tld)s", {'tld': tld})
 
         response.status_int = 200
 
@@ -127,7 +125,7 @@ class TldsController(rest.RestController):
 
         tld = self.central_api.delete_tld(context, tld_id)
 
-        LOG.info(_LI("Deleted %(tld)s"), {'tld': tld})
+        LOG.info("Deleted %(tld)s", {'tld': tld})
 
         response.status_int = 204
 
