@@ -15,8 +15,6 @@
 
 import gettext
 
-import six
-
 from designate import exceptions
 
 _ = gettext.gettext
@@ -43,7 +41,7 @@ class InfobloxExceptionBase(exceptions.Backend):
                 super(InfobloxExceptionBase, self).__init__(self.message)
 
     def __unicode__(self):
-        return six.text_type(self.msg)
+        return str(self.msg)
 
     def use_fatal_exceptions(self):
         return False
@@ -90,7 +88,7 @@ class InfobloxCannotUpdateObject(InfobloxException):
 
 
 class InfobloxFuncException(InfobloxException):
-    message = _("Error occured during function's '%(func_name)s' call: "
+    message = _("Error occurred during function's '%(func_name)s' call: "
                 "ref %(ref)s: %(content)s [code %(code)s]")
 
 
