@@ -22,12 +22,11 @@ import random
 import socket
 import ssl
 
-import six
 import eventlet
 from oslo_log import log as logging
 
-from designate import exceptions
 from designate.backend import base
+from designate import exceptions
 
 
 LOG = logging.getLogger(__name__)
@@ -52,17 +51,17 @@ class NSD4Backend(base.Backend):
         self.pattern = self.options.get('pattern', 'slave')
 
     def _command(self, command):
-            sock = eventlet.wrap_ssl(
-                eventlet.connect((self.host, self.port)),
-                keyfile=self.keyfile,
-                certfile=self.certfile)
-            stream = sock.makefile()
-            stream.write('%s %s\n' % (self.NSDCT_VERSION, command))
-            stream.flush()
-            result = stream.read()
-            stream.close()
-            sock.close()
-            return result
+        sock = eventlet.wrap_ssl(
+            eventlet.connect((self.host, self.port)),
+            keyfile=self.keyfile,
+            certfile=self.certfile)
+        stream = sock.makefile()
+        stream.write('%s %s\n' % (self.NSDCT_VERSION, command))
+        stream.flush()
+        result = stream.read()
+        stream.close()
+        sock.close()
+        return result
 
     def _execute_nsd4(self, command):
         try:
@@ -92,7 +91,7 @@ class NSD4Backend(base.Backend):
             self._execute_nsd4(command)
         except exceptions.Backend as e:
             # If create fails because the zone exists, don't reraise
-            if "already exists" not in six.text_type(e):
+            if "already exists" not in str(e):
                 raise
 
     def delete_zone(self, context, zone):
@@ -103,5 +102,5 @@ class NSD4Backend(base.Backend):
             self._execute_nsd4(command)
         except exceptions.Backend as e:
             # If zone is already deleted, don't reraise
-            if "not found" not in six.text_type(e):
+            if "not found" not in str(e):
                 raise
