@@ -29,6 +29,12 @@ from designate import utils
 from designate import version
 
 eventlet.monkey_patch(os=False)
+# Monkey patch the original current_thread to use the up-to-date _active
+# global variable. See https://bugs.launchpad.net/bugs/1863021 and
+# https://github.com/eventlet/eventlet/issues/592
+import __original_module_threading as orig_threading  # noqa
+import threading  # noqa
+orig_threading.current_thread.__globals__['_active'] = threading._active
 
 CONF = designate.conf.CONF
 
@@ -89,7 +95,7 @@ def get_arg_string(args):
     else:
         arg = args
 
-    return arg
+    return arg.replace('-', '_')
 
 
 def fetch_func_args(func):
