@@ -18,38 +18,38 @@ from oslo_policy import policy
 
 from designate.common.policies import base
 
-DEPERCATED_REASON = """
+DEPRECATED_REASON = """
 The tsigkey API now supports system scope and default roles.
 """
 
 deprecated_create_tsigkey = policy.DeprecatedRule(
     name="create_tsigkey",
     check_str=base.RULE_ADMIN,
-    deprecated_reason=DEPERCATED_REASON,
+    deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_find_tsigkeys = policy.DeprecatedRule(
     name="find_tsigkeys",
     check_str=base.RULE_ADMIN,
-    deprecated_reason=DEPERCATED_REASON,
+    deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_get_tsigkey = policy.DeprecatedRule(
     name="get_tsigkey",
     check_str=base.RULE_ADMIN,
-    deprecated_reason=DEPERCATED_REASON,
+    deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_update_tsigkey = policy.DeprecatedRule(
     name="update_tsigkey",
     check_str=base.RULE_ADMIN,
-    deprecated_reason=DEPERCATED_REASON,
+    deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_delete_tsigkey = policy.DeprecatedRule(
     name="delete_tsigkey",
     check_str=base.RULE_ADMIN,
-    deprecated_reason=DEPERCATED_REASON,
+    deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
 
@@ -88,9 +88,6 @@ rules = [
         description="Show a Tsigkey",
         operations=[
             {
-                'path': '/v2/tsigkeys/{tsigkey_id}',
-                'method': 'PATCH'
-            }, {
                 'path': '/v2/tsigkeys/{tsigkey_id}',
                 'method': 'GET'
             }
