@@ -24,27 +24,39 @@ The zone transfer accept API now supports system scope and default roles.
 
 deprecated_create_zone_transfer_accept = policy.DeprecatedRule(
     name="create_zone_transfer_accept",
-    check_str=base.RULE_ZONE_TRANSFER
+    check_str=base.LEGACY_RULE_ZONE_TRANSFER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_get_zone_transfer_accept = policy.DeprecatedRule(
     name="get_zone_transfer_accept",
-    check_str=base.RULE_ADMIN_OR_OWNER
+    check_str=base.RULE_ADMIN_OR_OWNER,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_find_zone_transfer_accepts = policy.DeprecatedRule(
     name="find_zone_transfer_accepts",
-    check_str=base.RULE_ADMIN
+    check_str=base.RULE_ADMIN,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_find_zone_transfer_accept = policy.DeprecatedRule(
     name="find_zone_transfer_accept",
-    check_str=base.RULE_ADMIN
+    check_str=base.RULE_ADMIN,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_update_zone_transfer_accept = policy.DeprecatedRule(
     name="update_zone_transfer_accept",
-    check_str=base.RULE_ADMIN
+    check_str=base.RULE_ADMIN,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_delete_zone_transfer_accept = policy.DeprecatedRule(
     name="delete_zone_transfer_accept",
-    check_str=base.RULE_ADMIN
+    check_str=base.RULE_ADMIN,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
 )
 
 
@@ -52,13 +64,15 @@ rules = [
     policy.DocumentedRuleDefault(
         name="create_zone_transfer_accept",
         check_str=base.RULE_ZONE_TRANSFER,
+        scope_types=['system', 'project'],
         description="Create Zone Transfer Accept",
         operations=[
             {
                 'path': '/v2/zones/tasks/transfer_accepts',
                 'method': 'POST'
             }
-        ]
+        ],
+        deprecated_rule=deprecated_create_zone_transfer_accept
     ),
     policy.DocumentedRuleDefault(
         name="get_zone_transfer_accept",
@@ -71,9 +85,7 @@ rules = [
                 'method': 'GET'
             }
         ],
-        deprecated_rule=deprecated_get_zone_transfer_accept,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_get_zone_transfer_accept
     ),
     policy.DocumentedRuleDefault(
         name="find_zone_transfer_accepts",
@@ -86,17 +98,13 @@ rules = [
                 'method': 'GET'
             }
         ],
-        deprecated_rule=deprecated_find_zone_transfer_accepts,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_find_zone_transfer_accepts
     ),
     policy.RuleDefault(
         name="find_zone_transfer_accept",
         check_str=base.SYSTEM_READER,
         scope_types=['system'],
-        deprecated_rule=deprecated_find_zone_transfer_accept,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_find_zone_transfer_accept
     ),
     policy.DocumentedRuleDefault(
         name="update_zone_transfer_accept",
@@ -109,17 +117,13 @@ rules = [
                 'method': 'POST'
             }
         ],
-        deprecated_rule=deprecated_update_zone_transfer_accept,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_update_zone_transfer_accept
     ),
     policy.RuleDefault(
         name="delete_zone_transfer_accept",
         check_str=base.SYSTEM_ADMIN,
         scope_types=['system'],
-        deprecated_rule=deprecated_delete_zone_transfer_accept,
-        deprecated_reason=DEPRECATED_REASON,
-        deprecated_since=versionutils.deprecated.WALLABY
+        deprecated_rule=deprecated_delete_zone_transfer_accept
     )
 ]
 
