@@ -13,12 +13,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import oslo_messaging as messaging
 from oslo_log import log as logging
+import oslo_messaging as messaging
 
-from designate.pool_manager import rpcapi as pool_mngr_api
 from designate.central import rpcapi as central_api
-from designate.i18n import _LI
 
 LOG = logging.getLogger(__name__)
 
@@ -29,7 +27,7 @@ class BaseEndpoint(object):
     RPC_API_VERSION = None
 
     def __init__(self, tg):
-        LOG.info(_LI("Initialized mDNS %s endpoint"), self.RPC_API_NAMESPACE)
+        LOG.info("Initialized mDNS %s endpoint", self.RPC_API_NAMESPACE)
         self.tg = tg
         self.target = messaging.Target(
             namespace=self.RPC_API_NAMESPACE,
@@ -38,7 +36,3 @@ class BaseEndpoint(object):
     @property
     def central_api(self):
         return central_api.CentralAPI.get_instance()
-
-    @property
-    def pool_manager_api(self):
-        return pool_mngr_api.PoolManagerAPI.get_instance()
