@@ -22,10 +22,9 @@ import dns.rdataclass
 import dns.rdatatype
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
-from designate import exceptions
 from designate.central import rpcapi as central_api
+from designate import exceptions
 from designate.mdns import xfr
 
 LOG = logging.getLogger(__name__)
@@ -41,12 +40,14 @@ TSIG_RRSIZE = 10 + 64 + 160 + 1
 
 class RequestHandler(xfr.XFRMixin):
     def __init__(self, storage, tg):
+        self._central_api = None
+
         self.storage = storage
         self.tg = tg
 
     @property
     def central_api(self):
-        if not hasattr(self, '_central_api'):
+        if not self._central_api:
             self._central_api = central_api.CentralAPI.get_instance()
         return self._central_api
 
@@ -109,7 +110,7 @@ class RequestHandler(xfr.XFRMixin):
             question = request.question[0]
 
         name = question.name.to_text()
-        if six.PY3 and isinstance(name, bytes):
+        if isinstance(name, bytes):
             name = name.decode('utf-8')
 
         criterion = {
@@ -207,7 +208,7 @@ class RequestHandler(xfr.XFRMixin):
         # validate the parameters
         try:
             name = q_rrset.name.to_text()
-            if six.PY3 and isinstance(name, bytes):
+            if isinstance(name, bytes):
                 name = name.decode('utf-8')
             criterion = self._zone_criterion_from_request(
                 request, {'name': name})
@@ -237,6 +238,10 @@ class RequestHandler(xfr.XFRMixin):
         records.insert(0, soa_records[0])
         records.append(soa_records[0])
 
+        # Handle multi message response with tsig
+        multi_messages = False
+        multi_messages_context = None
+
         # Render the results, yielding a packet after each TooBig exception.
         renderer = None
         while records:
@@ -258,6 +263,9 @@ class RequestHandler(xfr.XFRMixin):
                     renderer.add_rrset(dns.renderer.ANSWER, rrset)
                     break
                 except dns.exception.TooBig:
+                    # The response will span multiple messages since one
+                    # message is not enough
+                    multi_messages = True
                     if renderer.counts[dns.renderer.ANSWER] == 0:
                         # We've received a TooBig from the first attempted
                         # RRSet in this packet. Log a warning and abort the
@@ -278,11 +286,16 @@ class RequestHandler(xfr.XFRMixin):
                         )
                         return
 
-                    yield self._finalize_packet(renderer, request)
+                    renderer, multi_messages_context = self._finalize_packet(
+                        renderer, request, multi_messages,
+                        multi_messages_context)
+                    yield renderer
                     renderer = None
 
         if renderer:
-            yield self._finalize_packet(renderer, request)
+            renderer, multi_messages_context = self._finalize_packet(
+                renderer, request, multi_messages, multi_messages_context)
+            yield renderer
         return
 
     def _handle_record_query(self, request):
@@ -293,7 +306,7 @@ class RequestHandler(xfr.XFRMixin):
         try:
             q_rrset = request.question[0]
             name = q_rrset.name.to_text()
-            if six.PY3 and isinstance(name, bytes):
+            if isinstance(name, bytes):
                 name = name.decode('utf-8')
             # TODO(vinod) once validation is separated from the api,
             # validate the parameters
@@ -394,22 +407,26 @@ class RequestHandler(xfr.XFRMixin):
             recordset.name, ttl, dns.rdataclass.IN, recordset.type, rdata)
 
     @staticmethod
-    def _finalize_packet(renderer, request):
+    def _finalize_packet(renderer, request, multi_messages=False,
+                         multi_messages_context=None):
         renderer.write_header()
         if request.had_tsig:
             # Make the space we reserved for TSIG available for use
             renderer.max_size += TSIG_RRSIZE
-            renderer.add_tsig(
-                request.keyname,
-                request.keyring[request.keyname],
-                request.fudge,
-                request.original_id,
-                request.tsig_error,
-                request.other_data,
-                request.mac,
-                request.keyalgorithm
-            )
-        return renderer
+            if multi_messages:
+                # The first message context will be None then the
+                # context for the prev message is used for the next
+                multi_messages_context = renderer.add_multi_tsig(
+                    multi_messages_context, request.keyname,
+                    request.keyring[request.keyname], request.fudge,
+                    request.original_id, request.tsig_error,
+                    request.other_data, request.mac, request.keyalgorithm)
+            else:
+                renderer.add_tsig(request.keyname,
+                    request.keyring[request.keyname], request.fudge,
+                    request.original_id, request.tsig_error,
+                    request.other_data, request.mac, request.keyalgorithm)
+        return renderer, multi_messages_context
 
     @staticmethod
     def _get_max_message_size(had_tsig):
