@@ -19,23 +19,14 @@ import abc
 
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
-from designate.plugin import DriverPlugin
+import designate.conf
 from designate import objects
+from designate.plugin import DriverPlugin
 from designate import rpc
 
 LOG = logging.getLogger(__name__)
-
-notify_opts = [
-    cfg.BoolOpt('notify_api_faults', default=False,
-                help='Send notifications if there\'s a failure in the API.'),
-    cfg.StrOpt('notification-plugin', default='default',
-               help='The notification plugin to use'),
-]
-
-CONF = cfg.CONF
-CONF.register_opts(notify_opts)
+CONF = designate.conf.CONF
 NOTIFICATION_PLUGIN = None
 
 
@@ -160,7 +151,7 @@ class Audit(NotificationPlugin):
                         # Just in case something odd makes it here
                         if any(not isinstance(val,
                                               (int, float, bool,
-                                               six.string_types, type(None)))
+                                               str, type(None)))
                                for val in (old_value, new_value)):
                             LOG.warning("Nulling notification values after "
                                         "unexpected values (%s, %s)",
