@@ -11,9 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from designate.objects.adapters.api_v2 import base
 from designate import objects
+from designate.objects.adapters.api_v2 import base
 
 
 class ServiceStatusAPIv2Adapter(base.APIv2Adapter):
@@ -44,8 +43,10 @@ class ServiceStatusAPIv2Adapter(base.APIv2Adapter):
         obj = super(ServiceStatusAPIv2Adapter, cls)._render_object(
             object, *args, **kwargs)
 
-        obj['links']['self'] = \
-            '%s/v2/%s/%s' % (cls.BASE_URI, 'service_statuses', obj['id'])
+        obj['links']['self'] = (
+                '%s/v2/%s/%s' % (cls._get_base_url(kwargs['request']),
+                                 'service_statuses', obj['id'])
+        )
 
         return obj
 
