@@ -13,11 +13,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
-
-from designate.objects.adapters.api_v2 import base
 from designate import objects
-LOG = logging.getLogger(__name__)
+from designate.objects.adapters.api_v2 import base
 
 
 class ZoneExportAPIv2Adapter(base.APIv2Adapter):
@@ -30,9 +27,7 @@ class ZoneExportAPIv2Adapter(base.APIv2Adapter):
             "status": {},
             "message": {},
             "location": {},
-            "zone_id": {
-                'rename': 'zone_id',
-            },
+            "zone_id": {},
             "project_id": {
                 'rename': 'tenant_id'
             },
@@ -48,7 +43,7 @@ class ZoneExportAPIv2Adapter(base.APIv2Adapter):
     }
 
     @classmethod
-    def _get_path(cls, request):
+    def _get_path(cls, request, *args):
         return '/v2/zones/tasks/exports'
 
     @classmethod
