@@ -12,32 +12,21 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from designate.objects import base
+from designate.objects import fields
 from designate.objects.record import Record
 from designate.objects.record import RecordList
 
 
+@base.DesignateRegistry.register
 class MX(Record):
     """
     MX Resource Record Type
     Defined in: RFC1035
     """
-    FIELDS = {
-        'priority': {
-            'schema': {
-                'type': 'integer',
-                'minimum': 0,
-                'maximum': 65535
-            },
-            'required': True
-        },
-        'exchange': {
-            'schema': {
-                'type': 'string',
-                'format': 'domainname',
-                'maxLength': 255,
-            },
-            'required': True
-        }
+    fields = {
+        'priority': fields.IntegerFields(minimum=0, maximum=65535),
+        'exchange': fields.StringFields(maxLength=255),
     }
 
     def _to_string(self):
@@ -57,6 +46,11 @@ class MX(Record):
     RECORD_TYPE = 15
 
 
+@base.DesignateRegistry.register
 class MXList(RecordList):
 
     LIST_ITEM_TYPE = MX
+
+    fields = {
+        'objects': fields.ListOfObjectsField('MX'),
+    }
