@@ -15,19 +15,18 @@
 # under the License.
 import datetime
 
+from designate.central import rpcapi
 from designate import context
 from designate import plugin
 from designate import rpc
-from designate.central import rpcapi
 from designate.worker import rpcapi as worker_rpcapi
-from designate.pool_manager import rpcapi as pool_manager_rpcapi
-from designate.i18n import _LI
 
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import timeutils
 
 LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
 
 
 class PeriodicTask(plugin.ExtensionPlugin):
@@ -35,24 +34,10 @@ class PeriodicTask(plugin.ExtensionPlugin):
     """
     __plugin_ns__ = 'designate.producer_tasks'
     __plugin_type__ = 'producer_task'
-    __interval__ = None
 
     def __init__(self):
+        super(PeriodicTask, self).__init__()
         self.my_partitions = None
-        self.options = cfg.CONF[self.get_canonical_name()]
-
-    @classmethod
-    def get_base_opts(cls):
-        options = [
-            cfg.IntOpt(
-                'interval',
-                default=cls.__interval__,
-                help='Run interval in seconds'
-            ),
-            cfg.IntOpt('per_page', default=100,
-                help='Default amount of results returned per page'),
-        ]
-        return options
 
     @property
     def central_api(self):
@@ -62,16 +47,9 @@ class PeriodicTask(plugin.ExtensionPlugin):
     def worker_api(self):
         return worker_rpcapi.WorkerAPI.get_instance()
 
-    @property
-    def pool_manager_api(self):
-        return pool_manager_rpcapi.PoolManagerAPI.get_instance()
-
     @property
     def zone_api(self):
-        # TODO(timsim): Remove this when pool_manager_api is gone
-        if cfg.CONF['service:worker'].enabled:
-                return self.worker_api
-        return self.pool_manager_api
+        return self.worker_api
 
     def on_partition_change(self, my_partitions, members, event):
         """Refresh partitions attribute
@@ -89,13 +67,13 @@ class PeriodicTask(plugin.ExtensionPlugin):
         return {col: "BETWEEN %s,%s" % self._my_range()}
 
     def _iter(self, method, *args, **kwargs):
-        kwargs.setdefault("limit", self.options.per_page)
+        kwargs.setdefault("limit", CONF[self.name].per_page)
         while True:
             items = method(*args, **kwargs)
 
             # Stop fetching if there's no more items
             if len(items) == 0:
-                raise StopIteration
+                return
             else:
                 kwargs["marker"] = items[-1].id
 
@@ -113,40 +91,24 @@ class DeletedZonePurgeTask(PeriodicTask):
     Deleted zones have values in the deleted_at column.
     Purging means removing them from the database entirely.
     """
-
     __plugin_name__ = 'zone_purge'
-    __interval__ = 3600
 
     def __init__(self):
         super(DeletedZonePurgeTask, self).__init__()
 
-    @classmethod
-    def get_cfg_opts(cls):
-        group = cfg.OptGroup(cls.get_canonical_name())
-        options = cls.get_base_opts() + [
-            cfg.IntOpt(
-                'time_threshold',
-                default=604800,
-                help="How old deleted zones should be (deleted_at) to be "
-                "purged, in seconds"
-            ),
-            cfg.IntOpt(
-                'batch_size',
-                default=100,
-                help='How many zones to be purged on each run'
-            ),
-        ]
-        return [(group, options)]
-
     def __call__(self):
         """Call the Central API to perform a purge of deleted zones based on
         expiration time and sharding range.
         """
         pstart, pend = self._my_range()
-        msg = _LI("Performing deleted zone purging for %(start)s to %(end)s")
-        LOG.info(msg, {"start": pstart, "end": pend})
+        LOG.info(
+            "Performing deleted zone purging for %(start)s to %(end)s",
+            {
+                "start": pstart,
+                "end": pend
+            })
 
-        delta = datetime.timedelta(seconds=self.options.time_threshold)
+        delta = datetime.timedelta(seconds=CONF[self.name].time_threshold)
         time_threshold = timeutils.utcnow() - delta
         LOG.debug("Filtering deleted zones before %s", time_threshold)
 
@@ -160,24 +122,17 @@ class DeletedZonePurgeTask(PeriodicTask):
         self.central_api.purge_zones(
             ctxt,
             criterion,
-            limit=self.options.batch_size,
+            limit=CONF[self.name].batch_size,
         )
 
 
 class PeriodicExistsTask(PeriodicTask):
     __plugin_name__ = 'periodic_exists'
-    __interval__ = 3600
 
     def __init__(self):
         super(PeriodicExistsTask, self).__init__()
         self.notifier = rpc.get_notifier('producer')
 
-    @classmethod
-    def get_cfg_opts(cls):
-        group = cfg.OptGroup(cls.get_canonical_name())
-        options = cls.get_base_opts()
-        return [(group, options)]
-
     @staticmethod
     def _get_period(seconds):
         interval = datetime.timedelta(seconds=seconds)
@@ -187,13 +142,17 @@ class PeriodicExistsTask(PeriodicTask):
     def __call__(self):
         pstart, pend = self._my_range()
 
-        msg = _LI("Emitting zone exist events for shards %(start)s to %(end)s")
-        LOG.info(msg, {"start": pstart, "end": pend})
+        LOG.info(
+            "Emitting zone exist events for shards %(start)s to %(end)s",
+            {
+                "start": pstart,
+                "end": pend
+            })
 
         ctxt = context.DesignateContext.get_admin_context()
         ctxt.all_tenants = True
 
-        start, end = self._get_period(self.options.interval)
+        start, end = self._get_period(CONF[self.name].interval)
 
         extra_data = {
             "audit_period_beginning": start,
@@ -211,25 +170,27 @@ class PeriodicExistsTask(PeriodicTask):
             self.notifier.info(ctxt, 'dns.domain.exists', zone_data)
             self.notifier.info(ctxt, 'dns.zone.exists', zone_data)
 
-        LOG.info(_LI("Finished emitting %(counter)d events for shards "
-                     "%(start)s to %(end)s"),
-                 {"start": pstart, "end": pend, "counter": counter})
+        LOG.info(
+            "Finished emitting %(counter)d events for shards "
+            "%(start)s to %(end)s",
+            {
+                "start": pstart,
+                "end": pend,
+                "counter": counter
+            })
 
 
 class PeriodicSecondaryRefreshTask(PeriodicTask):
     __plugin_name__ = 'periodic_secondary_refresh'
-    __interval__ = 3600
-
-    @classmethod
-    def get_cfg_opts(cls):
-        group = cfg.OptGroup(cls.get_canonical_name())
-        options = cls.get_base_opts()
-        return [(group, options)]
 
     def __call__(self):
         pstart, pend = self._my_range()
-        msg = _LI("Refreshing zones for shards %(start)s to %(end)s")
-        LOG.info(msg, {"start": pstart, "end": pend})
+        LOG.info(
+            "Refreshing zones for shards %(start)s to %(end)s",
+            {
+                "start": pstart,
+                "end": pend
+            })
 
         ctxt = context.DesignateContext.get_admin_context()
         ctxt.all_tenants = True
@@ -259,30 +220,11 @@ class PeriodicGenerateDelayedNotifyTask(PeriodicTask):
     """Generate delayed NOTIFY transactions
     Scan the database for zones with the delayed_notify flag set.
     """
-
     __plugin_name__ = 'delayed_notify'
-    __interval__ = 5
 
     def __init__(self):
         super(PeriodicGenerateDelayedNotifyTask, self).__init__()
 
-    @classmethod
-    def get_cfg_opts(cls):
-        group = cfg.OptGroup(cls.get_canonical_name())
-        options = cls.get_base_opts() + [
-            cfg.IntOpt(
-                'interval',
-                default=cls.__interval__,
-                help='Run interval in seconds'
-            ),
-            cfg.IntOpt(
-                'batch_size',
-                default=100,
-                help='How many zones to receive NOTIFY on each run'
-            ),
-        ]
-        return [(group, options)]
-
     def __call__(self):
         """Fetch a list of zones with the delayed_notify flag set up to
         "batch_size"
@@ -302,44 +244,34 @@ class PeriodicGenerateDelayedNotifyTask(PeriodicTask):
         zones = self.central_api.find_zones(
             ctxt,
             criterion,
-            limit=self.options.batch_size,
+            limit=CONF[self.name].batch_size,
             sort_key='updated_at',
             sort_dir='asc',
         )
 
-        msg = _LI("Performing delayed NOTIFY for %(start)s to %(end)s: %(n)d")
-        LOG.debug(msg % dict(start=pstart, end=pend, n=len(zones)))
-
-        for z in zones:
-            self.zone_api.update_zone(ctxt, z)
-            z.delayed_notify = False
-            self.central_api.update_zone(ctxt, z)
+        for zone in zones:
+            self.zone_api.update_zone(ctxt, zone)
+            zone.delayed_notify = False
+            self.central_api.update_zone(ctxt, zone)
+            LOG.debug(
+                'Performed delayed NOTIFY for %(id)s',
+                {
+                    'id': zone.id,
+                }
+            )
 
 
 class WorkerPeriodicRecovery(PeriodicTask):
     __plugin_name__ = 'worker_periodic_recovery'
-    __interval__ = 120
-
-    @classmethod
-    def get_cfg_opts(cls):
-        group = cfg.OptGroup(cls.get_canonical_name())
-        options = cls.get_base_opts() + [
-            cfg.IntOpt(
-                'interval',
-                default=cls.__interval__,
-                help='Run interval in seconds'
-            ),
-        ]
-        return [(group, options)]
 
     def __call__(self):
-        # TODO(timsim): Remove this when worker is always on
-        if not cfg.CONF['service:worker'].enabled:
-                return
-
         pstart, pend = self._my_range()
-        msg = _LI("Recovering zones for shards %(start)s to %(end)s")
-        LOG.info(msg, {"start": pstart, "end": pend})
+        LOG.info(
+            "Recovering zones for shards %(start)s to %(end)s",
+            {
+                "start": pstart,
+                "end": pend
+            })
 
         ctxt = context.DesignateContext.get_admin_context()
         ctxt.all_tenants = True
