@@ -17,9 +17,9 @@ from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate import exceptions
-from designate import storage
 from designate import objects
 from designate.quota import base
+from designate import storage
 from designate.storage import transaction
 
 
@@ -72,7 +72,7 @@ class StorageQuota(base.Quota):
 
         if resource not in list(self.get_default_quotas(context).keys()):
             raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
-                                                  "resource" % resource)
+                                                  "resource", resource)
 
         try:
             create_quota()
