@@ -13,12 +13,11 @@
 # under the License.
 from oslo_config import cfg
 
-from designate.scheduler.filters.base import Filter
-from designate.objects import Pool
-from designate.objects import PoolList
+from designate import objects
+from designate.scheduler.filters import base
 
 
-class DefaultPoolFilter(Filter):
+class DefaultPoolFilter(base.Filter):
     """This filter will always return the default pool specified in the
     designate config file
 
@@ -35,6 +34,7 @@ class DefaultPoolFilter(Filter):
     """
 
     def filter(self, context, pools, zone):
-        pools = PoolList()
-        pools.append(Pool(id=cfg.CONF['service:central'].default_pool_id))
+        pools = objects.PoolList()
+        pools.append(
+            objects.Pool(id=cfg.CONF['service:central'].default_pool_id))
         return pools
