@@ -14,15 +14,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import mock
+from unittest import mock
+
 from oslo_config import cfg
 from oslo_messaging.notify import notifier
 
-from designate.tests.test_api import ApiTestCase
+from designate.api import middleware
 from designate import context
 from designate import exceptions
 from designate import rpc
-from designate.api import middleware
+from designate.tests.test_api import ApiTestCase
 
 
 class FakeRequest(object):
@@ -101,7 +102,8 @@ class KeystoneContextMiddlewareTest(ApiTestCase):
         # Process the request
         response = app(request)
 
-        self.assertEqual(401, response.status_code)
+        # Ensure request was not blocked
+        self.assertEqual(response, 'FakeResponse')
 
 
 class NoAuthContextMiddlewareTest(ApiTestCase):
