@@ -15,11 +15,12 @@
 # under the License.
 from unittest.mock import patch
 
-import oslo_messaging as messaging
 from oslo_log import log as logging
+import oslo_messaging as messaging
 
-from designate import exceptions
 from designate.central import service as central_service
+from designate import exceptions
+from designate import objects
 from designate.tests.test_api.test_v2 import ApiV2TestCase
 
 LOG = logging.getLogger(__name__)
@@ -369,6 +370,32 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
         self._assert_exception('timeout', 504, self.client.get, url)
 
     def test_get_deleted_recordsets(self):
+        zone = self.create_zone(fixture=1)
+        recordset = self.create_recordset(zone, records=[])
+        url = '/zones/%s/recordsets' % zone['id']
+
+        response = self.client.get(url)
+
+        # Check the headers are what we expect
+        self.assertEqual(200, response.status_int)
+
+        # Now delete the recordset
+        url = '/zones/%s/recordsets/%s' % (zone['id'], recordset.id)
+        self.client.delete(url, status=202)
+
+        # Simulate the zone having been deleted on the backend
+        zone_serial = self.central_service.get_zone(
+            self.admin_context, zone['id']).serial
+        self.central_service.update_status(
+            self.admin_context, zone['id'], 'SUCCESS', zone_serial, 'UPDATE'
+        )
+
+        # Try to get the record and ensure that we get a
+        # recordset_not_found error
+        self._assert_exception('recordset_not_found', 404, self.client.get,
+                               url)
+
+    def test_get_deleted_recordset_after_deleting_zone(self):
         zone = self.create_zone(fixture=1)
         self.create_recordset(zone)
         url = '/zones/%s/recordsets' % zone['id']
@@ -378,21 +405,23 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
         # Check the headers are what we expect
         self.assertEqual(200, response.status_int)
 
-        # now delete the zone and get the recordsets
+        # Now delete the zone
         self.client.delete('/zones/%s' % zone['id'], status=202)
 
         # Simulate the zone having been deleted on the backend
         zone_serial = self.central_service.get_zone(
             self.admin_context, zone['id']).serial
         self.central_service.update_status(
-            self.admin_context, zone['id'], "SUCCESS", zone_serial)
+            self.admin_context, zone['id'], 'SUCCESS', zone_serial, 'DELETE'
+        )
 
-        # Check that we get a zone_not_found error
+        # Try to get the record and ensure that we get a
+        # zone_not_found error
         self._assert_exception('zone_not_found', 404, self.client.get, url)
 
     def test_get_recordset(self):
         # Create a recordset
-        recordset = self.create_recordset(self.zone)
+        recordset = self.create_recordset(self.zone, records=[])
 
         url = '/zones/%s/recordsets/%s' % (self.zone['id'], recordset['id'])
         response = self.client.get(url)
@@ -438,7 +467,7 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
 
     def test_update_recordset(self):
         # Create a recordset
-        recordset = self.create_recordset(self.zone)
+        recordset = self.create_recordset(self.zone, records=[])
 
         # Prepare an update body
         body = {'description': 'Tester'}
@@ -475,7 +504,7 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
 
     def test_update_recordset_with_record_create(self):
         # Create a recordset
-        recordset = self.create_recordset(self.zone, 'A')
+        recordset = self.create_recordset(self.zone, 'A', records=[])
 
         # The action and status are NONE and ACTIVE as there are no records
         self.assertEqual('NONE', recordset['action'])
@@ -515,7 +544,6 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
     def test_update_recordset_with_record_replace(self):
         # Create a recordset with one record
         recordset = self.create_recordset(self.zone, 'A')
-        self.create_record(self.zone, recordset)
 
         # Prepare an update body
         body = {'description': 'Tester',
@@ -549,7 +577,6 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
         # See bug #1474012
         new_zone = self.create_zone(name='example.net.')
         recordset = self.create_recordset(new_zone, 'TXT')
-        self.create_record(new_zone, recordset)
         body = {'description': 'Tester', 'records': ['a' * 255]}
 
         url = '/zones/%s/recordsets/%s' % (recordset['zone_id'],
@@ -560,17 +587,25 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
         # See bug #1474012
         new_zone = self.create_zone(name='example.net.')
         recordset = self.create_recordset(new_zone, 'TXT')
-        self.create_record(new_zone, recordset)
         body = {'description': 'Tester', 'records': ['a' * 512]}
         url = '/zones/%s/recordsets/%s' % (recordset['zone_id'],
                                            recordset['id'])
         self._assert_exception('invalid_object', 400,
                                self.client.put_json, url, body)
 
+    def test_create_txt_record_multiple_strings(self):
+        # create TXT record with string split in 2
+        new_zone = self.create_zone(name='example.net.')
+        recordset = self.create_recordset(new_zone, 'TXT')
+        record = '"{}" "{}"'.format('a' * 250, 'a' * 250)
+        body = {'description': 'Tester', 'records': [record]}
+        url = '/zones/%s/recordsets/%s' % (recordset['zone_id'],
+                                           recordset['id'])
+        self.client.put_json(url, body, status=202)
+
     def test_update_recordset_with_record_clear(self):
         # Create a recordset with one record
         recordset = self.create_recordset(self.zone, 'A')
-        self.create_record(self.zone, recordset)
 
         # Prepare an update body
         body = {'description': 'Tester', 'records': []}
@@ -706,7 +741,7 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
                                self.client.put_json, url, body)
 
     def test_delete_recordset(self):
-        recordset = self.create_recordset(self.zone)
+        recordset = self.create_recordset(self.zone, records=[])
 
         url = '/zones/%s/recordsets/%s' % (recordset['zone_id'],
                                            recordset['id'])
@@ -731,7 +766,6 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
     def test_delete_recordset_with_records(self):
         # Create a recordset with one record
         recordset = self.create_recordset(self.zone, 'A')
-        self.create_record(self.zone, recordset)
 
         url = '/zones/%s/recordsets/%s' % (recordset['zone_id'],
                                            recordset['id'])
@@ -815,11 +849,16 @@ class ApiV2RecordSetsTest(ApiV2TestCase):
 
         # Test paging
         new_zone = self.create_zone(name='example.net.')
-        recordset = self.create_recordset(new_zone, 'A')
-        self.create_record(new_zone, recordset, data='nyan')
-
-        recordset = self.create_recordset(new_zone, 'CNAME')
-        self.create_record(new_zone, recordset, data='nyan')
+        record_1 = objects.Record.from_dict({'data': 'nyan'})
+        self.create_recordset(
+            new_zone, 'A',
+            records=[record_1],
+        )
+        record_2 = objects.Record.from_dict({'data': 'nyan'})
+        self.create_recordset(
+            new_zone, 'CNAME',
+            records=[record_2],
+        )
 
         # Even with paging enabled, total_count is still the total number of
         # recordsets matching the "data" filter
