@@ -13,15 +13,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import mock
-from mock import patch
+from unittest import mock
+from unittest.mock import patch
+
 from oslo_config import cfg
 import oslo_messaging as messaging
 
-from designate import exceptions
-from designate import objects
 from designate.central import service as central_service
+from designate import exceptions
 from designate.mdns import rpcapi as mdns_api
+from designate import objects
 from designate.tests.test_api.test_v2 import ApiV2TestCase
 
 
@@ -519,9 +520,14 @@ class ApiV2ZonesTest(ApiV2TestCase):
 
     def test_update_secondary(self):
         # Create a zone
-        fixture = self.get_zone_fixture('SECONDARY', 0)
-
-        zone = objects.Zone(**fixture)
+        zone = objects.Zone(
+            name='example.com.',
+            type='SECONDARY',
+            masters=objects.ZoneMasterList.from_list([
+                {'host': '1.0.0.0', 'port': 69},
+                {'host': '2.0.0.0', 'port': 69}
+            ])
+        )
         zone.email = cfg.CONF['service:central'].managed_resource_email
 
         # Create a zone
