@@ -14,8 +14,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import operator
+from unittest import mock
 
-import mock
 import sqlalchemy as sa
 from sqlalchemy.sql import operators
 
