@@ -15,14 +15,14 @@
 # under the License.
 import socket
 import ssl
+from unittest import mock
 
 import eventlet
-import mock
 
-import designate.tests
+from designate.backend import impl_nsd4
 from designate import exceptions
 from designate import objects
-from designate.backend import impl_nsd4
+import designate.tests
 
 
 class NSD4BackendTestCase(designate.tests.TestCase):
