@@ -9,8 +9,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import oslotest.base
 from oslo_log import log as logging
+import oslotest.base
 
 from designate import exceptions
 from designate import objects
@@ -34,3 +34,13 @@ class RRDataTXTTest(oslotest.base.BaseTestCase):
             'Provided object does not match schema',
             record.validate
         )
+
+    def test_multiple_strings_one_record(self):
+        # these quotes do not have to be escaped as
+        # per rfc7208 3.3 and rfc1035 3.3.14
+        record = objects.TXT(data='"foo" "bar"')
+        self.assertRaisesRegex(
+            exceptions.InvalidObject,
+            'Provided object does not match schema',
+            record.validate
+        )
