@@ -17,14 +17,16 @@ from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
-from designate import rpc
+from designate.common import profiler
 from designate.loggingutils import rpc_logging
+from designate import rpc
 
 LOG = logging.getLogger(__name__)
 
 WORKER_API = None
 
 
+@profiler.trace_cls("rpc")
 @rpc_logging(LOG, 'worker')
 class WorkerAPI(object):
     """
@@ -37,9 +39,10 @@ class WorkerAPI(object):
     RPC_API_VERSION = '1.0'
 
     def __init__(self, topic=None):
-        topic = topic if topic else cfg.CONF['service:worker'].worker_topic
+        self.topic = topic if topic else cfg.CONF['service:worker'].topic
 
-        target = messaging.Target(topic=topic, version=self.RPC_API_VERSION)
+        target = messaging.Target(topic=self.topic,
+                                  version=self.RPC_API_VERSION)
         self.client = rpc.get_client(target, version_cap='1.0')
 
     @classmethod
