@@ -36,17 +36,18 @@
 from argparse import ArgumentParser
 from collections import OrderedDict
 from itertools import product
-from subprocess import check_output
-from subprocess import CalledProcessError
-from tempfile import NamedTemporaryFile
-from threading import Thread
-import json
 import logging
 import os
 import random
 import string
-import time
+from subprocess import CalledProcessError
+from subprocess import check_output
 import sys
+from tempfile import NamedTemporaryFile
+from threading import Thread
+import time
+
+from oslo_serialization import jsonutils
 
 import dns
 import dns.resolver
@@ -60,10 +61,10 @@ designate_cli_path = '/usr/local/bin/designate'
 openstack_cli = 'openstack'
 
 
-def gen_random_name(l):
+def gen_random_name(length):
     return "".join(
         random.choice(string.ascii_lowercase + string.digits)
-        for n in range(l)
+        for n in range(length)
     )
 
 
@@ -123,7 +124,7 @@ class DesignateCLI(object):
         log.debug("  running %s" % cmd)
         out = check_output(cmd, env=self._cli_env, shell=True,
                            executable='/bin/bash')
-        return json.loads(out)
+        return jsonutils.loads(out)
 
     def runcsv(self, cmd):
         """Run a command using the -f csv flag, parse the output
